@@ -7,13 +7,10 @@
 
 #include "dictP.h"
 
-#if HAVE_WCHAR_H
 #include <wchar.h>
-#endif
-
 #include <stdlib.h>
 
-int mbtowc (wchar_t *pwc, const char *s, size_t n)
+int mbtowc__ (wchar_t *pwc, const char *s, size_t n)
 {
-   return (int) mbrtowc (pwc, s, n, NULL);
+   return (int) mbrtowc__ (pwc, s, n, NULL);
 }
